@@ -573,16 +573,23 @@ Sam <- function(Data, MPs = NA, reps = 100, perc = 0.5) {
 #' Boxplot of TAC recommendations
 #' 
 #' @param x An object of class MSE
+#' @param upq Upper quantile of TACs for max ylim
+#' @param lwq Lower quantile of TACs for min ylim
 #' @param outline Logical. Include outliers in plot?
 #' @param ...  Optional additional arguments passed to \code{boxplot}
 #' @return Returns a data frame containing the information shown in the plot
 #' @author A. Hordyk
 #' @export
-boxplot.Data <- function(x, outline = FALSE, ...) {
+boxplot.Data <- function(x, upq=0.9, lwq=0.1, outline = FALSE, ...) {
   Data <- updateMSE(x)
-  if (class(Data) != "Data") 
-    stop("Object must be of class 'Data'")
+  if (class(Data) != "Data")  stop("Object must be of class 'Data'")
   tacs <- t(Data@TAC[, , 1])
+  if (all(is.na(tacs))) {
+    message("Nothing found in TAC slot")
+    return(invisible(NULL))
+  }
+  units <- TRUE
+  if (length(nchar(x@Units)) < 1) units <- FALSE
   MPs <- Data@MPs
   ind <- grep("ref", MPs)
   if (length(ind) > 0) {
@@ -594,13 +601,15 @@ boxplot.Data <- function(x, outline = FALSE, ...) {
     MPs <- MPs[ord]
     tacs <- tacs[, ord]
     cols <- rainbow(30)
-    ymax <- quantile(apply(tacs, 2, quantile, 0.99, na.rm = TRUE), 0.99)
-    ymin <- quantile(apply(tacs, 2, quantile, 0.01, na.rm = TRUE), 0.01)
-    ylim <- c(0, ymax)
+    # ymax <- quantile(apply(tacs, 2, quantile, upq, na.rm = TRUE), upq)
+    ymax <- max(apply(tacs, 2, quantile, upq, na.rm = TRUE))
+    # ymin <- quantile(apply(tacs, 2, quantile, lwq, na.rm = TRUE), lwq)
+    ymin <- min(apply(tacs, 2, quantile, lwq, na.rm = TRUE))
+    ylim <- c(ymin, ymax)
     Median <- round(apply(tacs, 2, median, na.rm = TRUE), 2)
     SD <- round(apply(tacs, 2, sd, na.rm = TRUE), 2)
   } else {
-    ylim <- c(0,max(tacs))
+    ylim <- c(quantile(tacs, lwq),quantile(tacs, upq))
     Median <- median(tacs)
     SD <- sd(tacs)
     tacs <- as.numeric(tacs)
@@ -611,13 +620,16 @@ boxplot.Data <- function(x, outline = FALSE, ...) {
   boxplot(tacs, names = MPs, las = 1, col = cols, outline = outline, 
     frame = FALSE, ylim = ylim, horizontal = TRUE, ...)
   
-  mtext(paste("TAC (", Data@Units, ")", sep = ""), side = 1, outer = T, 
-    line = 0.5, cex = 1.25)
+  if (units) mtext(paste("TAC (", Data@Units, ")", sep = ""), side = 1, outer = T, 
+                   line = 0.5, cex = 1.25)
+  if (!units) mtext("TAC (no units supplied)", side = 1, outer = T, 
+                    line = 0.5, cex = 1.25)
   mtext(side = 2, "Management Procedures", outer = TRUE, line = 3, cex = 1.25)
   mtext(paste("TAC calculation for ", Data@Name, sep = ""), 3, outer = T, 
     line = -0.5, cex = 1.25)
   
-  data.frame(MP = MPs, Median = Median, SD = SD, Units = Data@Units)
+  if (units) data.frame(MP = MPs, Median = Median, SD = SD, Units = Data@Units)
+  if (!units) data.frame(MP = MPs, Median = Median, SD = SD)
   
 }
 
